@@ -6,6 +6,12 @@ set -o errexit
 # Enable unbuffered output for Ansible in Jenkins.
 export PYTHONUNBUFFERED=1
 
+source /etc/nodepool/provider
+
+NODEPOOL_MIRROR_HOST=${NODEPOOL_MIRROR_HOST:-mirror.$NODEPOOL_REGION.$NODEPOOL_CLOUD.openstack.org}
+NODEPOOL_MIRROR_HOST=$(echo $NODEPOOL_MIRROR_HOST|tr '[:upper:]' '[:lower:]')
+NODEPOOL_PYPI_MIRROR=${NODEPOOL_PYPI_MIRROR:-http://$NODEPOOL_MIRROR_HOST/pypi/simple}
+
 # Just for mandre :)
 if [[ ! -f /etc/sudoers.d/jenkins ]]; then
     echo "jenkins ALL=(:docker) NOPASSWD: ALL" | sudo tee /etc/sudoers.d/jenkins
@@ -19,10 +25,22 @@ function setup_config {
     # Generate passwords
     sudo tools/generate_passwords.py
 
-    # Use Infra provided pypi
-    echo "RUN echo $(base64 -w0 /etc/pip.conf) | base64 -d > /etc/pip.conf" | sudo tee /etc/kolla/header
+    # Use Infra provided pypi.
+    # Wheel package mirror may be not compatible. So do not enable it.
+    PIP_CONF=$(mktemp)
+    cat > ${PIP_CONF} <<EOF
+[global]
+timeout = 60
+index-url = $NODEPOOL_PYPI_MIRROR
+trusted-host = $NODEPOOL_MIRROR_HOST
+EOF
+    echo "RUN echo $(base64 -w0 ${PIP_CONF}) | base64 -d > /etc/pip.conf" | sudo tee /etc/kolla/header
+    rm ${PIP_CONF}
     sed -i 's|^#include_header.*|include_header = /etc/kolla/header|' /etc/kolla/kolla-build.conf
 
+    # NOTE(Jeffrey4l): use different a docker namespace name in case it pull image from hub.docker.io when deplying
+    sed -i 's|^#namespace.*|namespace = lokolla|' /etc/kolla/kolla-build.conf
+
     if [[ "${DISTRO}" == "Debian" ]]; then
         # Infra does not sign thier mirrors so we ignore gpg signing in the gate
         echo "RUN echo 'APT::Get::AllowUnauthenticated \"true\";' > /etc/apt/apt.conf" | sudo tee -a /etc/kolla/header
@@ -30,18 +48,14 @@ function setup_config {
         # Optimize the repos to take advantage of the Infra provided mirrors for Ubuntu
         sed -i 's|^#apt_sources_list.*|apt_sources_list = /etc/kolla/sources.list|' /etc/kolla/kolla-build.conf
         sudo cp /etc/apt/sources.list /etc/kolla/sources.list
+        sudo cat /etc/apt/sources.list.available.d/ubuntu-cloud-archive.list | sudo tee -a /etc/kolla/sources.list
         # Append non-infra provided repos to list
         cat << EOF | sudo tee -a /etc/kolla/sources.list
-deb http://ubuntu-cloud.archive.canonical.com/ubuntu trusty-updates/mitaka main
 deb http://nyc2.mirrors.digitalocean.com/mariadb/repo/10.0/ubuntu trusty main
 deb http://repo.percona.com/apt trusty main
-deb http://download.ceph.com/debian-hammer/ trusty main
 deb http://packages.elastic.co/elasticsearch/2.x/debian stable main
 deb http://packages.elastic.co/kibana/4.4/debian stable main
 EOF
-    elif [[ "${DISTRO}" == "RedHat" ]]; then
-        # disable selinux
-        sudo setenforce Permissive
     fi
 }
 
@@ -64,7 +78,7 @@ function setup_ssh {
     ssh-keygen -f /home/jenkins/.ssh/kolla -N ''
     cat /home/jenkins/.ssh/kolla.pub >> /home/jenkins/.ssh/authorized_keys
 
-    # Push the the public key around to all of the nodes
+    # Push the public key around to all of the nodes
     for ip in $(cat /etc/nodepool/sub_nodes_private); do
         scp /home/jenkins/.ssh/kolla.pub ${ip}:/home/jenkins/.ssh/authorized_keys
         # TODO(SamYaple): Remove this root key pushing once Kolla doesn't
@@ -82,7 +96,7 @@ function setup_inventory {
     echo -e "127.0.0.1\tlocalhost" > /tmp/hosts
     for ip in $(cat /etc/nodepool/{node_private,sub_nodes_private}); do
         : $((counter++))
-        # FIXME(jeffrey4l): do not set two hostnames in one line. this is a
+        # FIXME(jeffrey4l): do not set two hostnames in oneline. this is a
         # wordround fix for the rabbitmq failed when deploy on CentOS in the CI
         # gate. the ideal fix should set the hostname in setup_gate.sh script.
         # But it do not work as expect with unknown reason
@@ -101,13 +115,20 @@ function setup_ansible {
     mkdir /tmp/kolla
 
     # TODO(SamYaple): Move to virtualenv
-    sudo -H pip install -U "ansible<2" "docker-py>=1.6.0" "python-openstackclient" "python-neutronclient"
+    sudo -H pip install -U "ansible>=2" "docker-py>=1.6.0" "python-openstackclient" "python-neutronclient"
     detect_distro
 
     setup_inventory
 
     # Record the running state of the environment as seen by the setup module
     ansible all -i ${RAW_INVENTORY} -m setup > /tmp/logs/ansible/initial-setup
+
+    sudo -H pip install ara
+    sudo mkdir /etc/ansible
+    sudo tee /etc/ansible/ansible.cfg<<EOF
+[defaults]
+callback_plugins = /usr/lib/python2.7/site-packages/ara/callback:\$VIRTUAL_ENV/lib/python2.7/site-packages/ara/callback:/usr/local/lib/python2.7/dist-packages/ara/callback
+EOF
 }
 
 function setup_node {
@@ -121,7 +142,7 @@ function setup_logging {
 
     # For ease of access we symlink that logs directory to a known path
     ln -s $(pwd)/logs /tmp/logs
-    mkdir -p /tmp/logs/{ansible,build,kolla}
+    mkdir -p /tmp/logs/{ansible,build,kolla,kolla_configs,system_logs}
 }
 
 setup_logging
